@@ -14,6 +14,7 @@ from artify import change_version
 from artify import generate_file
 from artify import extract_commands
 from artify import initialize
+from artify import archive
 
 debug = 0;
 
@@ -40,6 +41,8 @@ directory = ''
 group_id = ''
 auth = ''
 
+path = ''
+
 # Variables - Nexus
 
 # Variables - Deploy AWX
@@ -69,10 +72,19 @@ project_key = ''
 project_name = ''
 # Variables - Initialize
 
+# Variables - Archive
+archive_basename = ''
+archive_format = ''
+archive_rootdir = ''
+archive_basedir = ''
+options = ''
+# Variables - Archive
+
 def main(argv):  
-    print("Copyright \N{COPYRIGHT SIGN} 2020 Stewartium ::: artify v{}\n".format(__version__))
+    print("Copyright \N{COPYRIGHT SIGN} 2020 - 2021 Stewartium ::: artify v{}\n".format(__version__))
     action = ''
     
+    global path 
     path = os.path.abspath(os.getcwd()) 
     
     # Variables - Deploy AWX
@@ -114,16 +126,25 @@ def main(argv):
     global project_key
     global project_name
     # Variables - Initialize
+    
+    # Variables - Global
+    global archive_basedir
+    global archive_format
+    global archive_rootdir
+    global archive_basename
+    global options
+    # Variables - Global
    
     try:
-        opts, args = getopt.getopt(argv, "a:b:c:d:f:h:k:l:m:n:u:p:r:g:t:w:", ["command=", "help=", 
+        opts, args = getopt.getopt(argv, "a:b:c:d:f:h:k:l:m:n:o:u:p:r:g:t:w:", ["command=", "help=", 
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
                                                 "file=", "awxhost=","--host=",
                                                 "format=",
                                                 "type=", "archtype=", "prevalue=",
                                                 "message=", "branch=",
-                                                "projectkey=", "projectname="
-                                                "debug"
+                                                "projectkey=", "projectname=",
+                                                "debug",
+                                                "archivename=","rootdir=", "basedir=", "options="
                                                ])
     except getopt.GetoptError:
         print('Invalid syntax')
@@ -208,6 +229,15 @@ def main(argv):
                 print('\nExample command below for a java project that uses gradle build tool.')
                 print('\npython -m artify -c initialize -h <SonarQube_base_url> -u <username> -p <password> -l java -a gradle\n')
                 return sys.exit(0)
+            elif arg == 'archive':
+                print('Uses Shutil Python library to create archive file')
+                print('python -m artify -c archive -n <archive_name> -f <archive_format> -w <root_dir> -d <base_dir>')
+                print("Mandatory argument(s):")
+                print("-n, --archivename  Name for the archive file that will be created")
+                print("-f, --format       Format for the archive e.g dddddddd")
+                print("-w, --rootdir      Root directory is a directory that will be the root directory of the archive.")
+                print("-d, --basedir      Base directory is the directory where we start archiving from.")
+                return sys.exit(0)
             else:
                 print('python -m artify --help nexus        Help on how to deploy to Nexus Repository')
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
@@ -248,6 +278,11 @@ def main(argv):
                 # Generate file START
                 filename_gen = arg
                 # Generate file END
+            elif action == 'archive':
+                archive_format = arg
+                if archive_format == '':
+                    print('Please specify archive format e.g zip, tar, gztar, bztar, xztar')
+                    return sys.exit(2)
             else:
                 print("Invalid command specified: param: -f")
                      
@@ -295,26 +330,45 @@ def main(argv):
                 return sys.exit(2)
         
         ## -d 
-        elif opt in ("-d", "--directory"):
-            directory = arg
-            if directory == '':
+        elif opt in ("-d", "--directory", "--basedir"):
+            if action == 'archive':
+                archive_basedir = arg
+            else:
+                directory = arg
+            if directory == '' and action == 'nexus':
                 print("Please specify directory to store artifact for RAW respository")
                 return sys.exit(2)
             
+            if archive_basedir == '' and action == 'archive':
+                print('Please specify base directory i.e the folder to be archived.')
+                return sys.exit(2)
         
         ## -w
-        elif opt in ("-w", "--workdirectory"):
-            work_directory = arg
-            if work_directory == '':
+        elif opt in ("-w", "--workdirectory", "--rootdir"):
+            if action == 'archive':
+                archive_rootdir = arg
+            else:
+                work_directory = arg
+            if work_directory == '' and action == 'nexus':
                 work_directory = path
                 if work_directory == '':
                     print("Please specify artifact current directory")
                     return sys.exit(2)
+            if archive_rootdir == '' and action == 'archive':
+                archive_rootdir = path
+                if archive_rootdir == '':
+                    print('Please specify root directory for artifact.')
+                    return sys.exit(2)
          
         ## -n  
-        elif opt in ("-n", "--artifactname", "--projectname"):
+        elif opt in ("-n", "--artifactname", "--projectname", "--archivename"):
             if action == 'initialize':
                 project_name = arg
+            elif action == 'archive':
+                archive_basename = arg
+                if archive_basename == '':
+                    print('Please specify archive name e.g myfile')
+                    return sys.exit(2)
             else:
                 artifact_name = arg
                 if artifact_name == '':
@@ -351,6 +405,12 @@ def main(argv):
         
         ## Commit-push changes repository END
         
+        # Make archive START
+        elif opt in ("-o", "--options"):
+            options = arg
+            
+        # Make archive END
+        
         # Initialize START
         elif opt in ("-l", "--language"):
             language = arg
@@ -360,10 +420,10 @@ def main(argv):
         # Initialize END       
          
     if debug == 1:
-        print("Action entered: ", action)
+        print("DEBUG: Action entered: ", action)
     if action == 'nexus':
         nexus.setup_variables()
-        print("Nexus Format entered: ", nexus_format)
+        print("INFO: Nexus Format entered: ", nexus_format)
         if nexus_format == 'raw':
             nexus.upload_nexus_raw()
         elif nexus_format == 'npm':
@@ -391,6 +451,12 @@ def main(argv):
         #initialize.create_sonarq_project('test-frontend', 'goj-migration')   
         initialize.setup_variables()
         initialize.create_sonarq_project(project_name, project_key)
+    elif action == 'archive':           
+        result = archive.archive_file()
+        if result == '' or result == None:
+            print("Error: Failed to archive file.")
+        else:
+            print("INFO: File {} archived successfully.".format(result))
     elif action == '':
         print("Invalid action specified")
         return sys.exit(2)
