@@ -8,15 +8,9 @@ path = os.path.abspath(__main__.os.getcwd())
 
 template_manifest = "project_name: <project_name>\ngroup_id: <group_id>\nartifact_id: <git_artifact_name>\nversion: 1.0.0"
 template_gitlab_ci = "variables:\n   GIT_STRATEGY: clone\n\n" \
-                   "stages:\n  - updates\n  - build\n  - test\n  - upload\n  - deploy\n\n" \
+                   "stages:\n  - updates\n  - build\n  - test\n  - upload\n  - deploy\n  - security\n  - post-deploy\n\n" \
                     "search-commit:\n  stage: updates\n  script:\n     - echo Searching commit message for commands\n" \
                     "     - python -m artify -c extract\n  tags:\n    - <runner>\n\n" \
-                    "change-patch:\n  stage: updates\n  script:\n    - echo Updating version number - Patch\n" \
-                    "    #- python -m artify -c deltav -t patch -a <build_type>\n  only:\n    - feature/patch-version\n  tags:\n    - <runner>\n\n" \
-                    "change-minor:\n  stage: updates\n  script:\n    - echo Updating version number - Minor\n" \
-                    "    #- python -m artify -c deltav -t minor -a <build_type>\n  only:\n    - feature/minor-version\n  tags:\n    - <runner>\n\n" \
-                    "change-major:\n  stage: updates\n  script:\n    - echo Updating version number - Major\n" \
-                    "    #- python -m artify -c deltav -t major -a <build_type>\n  only:\n    - feature/major-version\n  tags:\n    - <runner>\n\n" \
                     "build-project:\n  stage: build\n  script:\n   - echo Building project\n" \
                     "    #- <put buildscript here>\n  tags:\n    - <runner>\n\n" \
                     "build-project-production:\n  stage: build\n  script:\n     - echo Building project for production\n" \
@@ -29,7 +23,12 @@ template_gitlab_ci = "variables:\n   GIT_STRATEGY: clone\n\n" \
                     "    #- python -m artify -c nexus -f <format> -n <artifact_name.zip/.war> -h <Nexus_repository_host>\n  tags:\n    - <runner>\n\n" \
                     "deploy-project:\n  stage: deploy\n  script:\n    - echo Deploying App to server\n" \
                     "    #- python -m artify -c deploy -f <manifest.yml> -h <awx_host>\n  tags:\n    - <runner>\n\n" \
-
+                    "security-test-ibmappscan:\n  stage: security\n  script:\n    - echo Perform IBM AppScan Test\n" \
+                    "    #- ibmscan.exe\n  tags:\n    - <security_runner>\n\n" \
+                    "security-test-arachni:\n  stage: security\n  script:\n    - echo Perform Security Test\n" \
+                    "    #- arachni <deploy_site_url>\n  tags:\n    - <security_runner>\n\n" \
+                    "create-tag:\n  stage: post-deploy\n  script:\n    - echo Attempting to tag artifact\n" \
+                    "    #- python -m artify -c syncrepo -m tag\n  only:\n    - master\n  tags:\n    - <runner>\n\n" \
     
 def write_to_file(contents, filename):
     filepath = os.path.join(path, filename)
